/**
  \file showbug.c
  
  \brief Source file to show parameter-line bug. \n
  \brief If a function definition's parametrization's opening bracket is set in a lower line, doxygen will set this function as a reference of the next higher function in the same file. \n
  \brief Filescope applies, so that the bug does not appear in the first defined funtion in a file. \n
  \brief If a variable is declared above the function, the bug does also not show. \n
  \brief General practice of defining functions above where they are used further hides this bug / complicates its deduction. \n
  \brief This bug occurs from Doxygen 1.8.11 onwards. Only tested for C programming language.
  
  \author Oliver S.
  \date   28.09.2017
 **/

#include <stdio.h> 
 
 
 void helloWorld()
 {
	 /**
		\brief - prints "Hello World" \n 
		\brief - is <b>not</b> calling anything nor referenced anywhere
	 **/
	 
	 printf("Hello World");
 };
 
 
int returnDouble
(
 int original_value 
)
 {
	 /**
		\brief - returns double the integer given \n
		\brief - while unusual, C allows for this type of function parametrization \n
		\brief - if you have multiple parameters, this can actually help readability		
	 **/
	 
	return original_value * 2;
 };

 
int main()
 {
	/**
		\brief - calls returnDouble 5 times with incrementing integers; should be thirty \n
		\brief - returns 0
	**/
	int thirty = 0;
	int i = 0;
	
	for(i = 1; i <= 5; i++)
	{
		thirty += returnDouble(i);
	};
	
	printf("This should be thirty: %i", thirty);
	
	return 0;
 };